from dtschema.lib import (
    add_schema_path,
    load_schema,
    load,
    set_schemas,
    DTValidator,
    format_error,
    extract_compatibles,
    extract_types,
    get_undocumented_compatibles,
    property_get_type,
    property_get_type_dim,
    property_has_fixed_dimensions,
    sized_int,
)

from dtschema.version import (
    __version__
)
